#!/usr/bin/env python
###################
# This script builds Python distribution archives from the project directory
# -> extra files (doc) are manually added since Python 2.3 disutils
#    does not provide any facility to do so
# -> to change file extensions of files to be zipped, edit MANIFEST.in
#
# Data install tip from:
#  http://wiki.python.org/moin/DistutilsInstallDataScattered
#
# Copyright Jean-Michel Philippe (c) 2007
#   <http://philipjm.free.fr/blog/>
#
# This is open source software released under the GPL license.
# The full text of this license is found in the file 'LICENSE',
# included with this source code package.
###################

# importations
from distutils.core import setup
from distutils.command.install_data import install_data
import sys, os, re

# sub-class install_data and tell it to use the install_lib directory as its root install directory
class smart_install_data(install_data):
	def run(self):
		#need to change self.install_dir to the library dir
		install_cmd = self.get_finalized_command('install')
		self.install_dir = getattr(install_cmd, 'install_lib')
		return install_data.run(self)

# data files
DBFiles = ['db/IpToCountry.csv']
DocFiles = [os.path.join('doc', x) for x in os.listdir('doc')]

# get the version number
FileId = open('__init__.py')
Text = FileId.read()
FileId.close()
__author__ = re.findall('__author__ = "([^"]+)"', Text)[0]
__url__ = re.findall('__url__ = "([^"]+)"', Text)[0]
__version__ = re.findall('__version__ = "([^"]+)"', Text)[0]

# build archives
setup(
	name='whois',
	version=__version__,
	packages = ['whois'],
	package_dir = {'whois': ''},
	data_files=[
		('whois/db', DBFiles),
		('whois/doc', DocFiles),
	],
	cmdclass = {'install_data':smart_install_data},
	description='Retrieves computer location from IP',
	author='Jean-Michel Philippe',
	platforms='any',
	author_email=__author__,
	url=__url__,
	license='GNU GPL v2',
	long_description="""
Guess host location from their IP, based on whois services.

2 method are implemented:

* IP searched in a local database
* IP searched on an Internet whois service

Search results are stored in a local database to speedup further identical
searches. Use of former results can be disabled. Internet whois search can
be disabled too.

Local databases can be downloaded/updated from:
   http://software77.net/cgi-bin/ip-country/geo-ip.pl
   http://ip-to-country.webhosting.info/node/view/6

Full Internet whois queries may also be accessed.
""",
)
